@@ -42,6 +42,7 @@ sanity_model_supported_class <- function(model) {
         "clm",
         c("clmm2", "clm2"),
         "coxph",
+        "coxph_weightit",
         "crch",
         "flexsurvreg", # package: flexsurv
         "fixest",
@@ -57,9 +58,11 @@ sanity_model_supported_class <- function(model) {
         "glmerMod",
         "glmrob",
         "glmmTMB",
+        "glmgee",
         c("glmmPQL", "lme"),
         "glimML",
         "glmx",
+        "glm_weightit",
         "hetprob",
         "hurdle",
         "hxlr",
@@ -87,16 +90,19 @@ sanity_model_supported_class <- function(model) {
         "mlogit",
         "model_fit",
         c("multinom", "nnet"),
+        "multinom_weightit",
         "mvgam",
         c("negbin", "glm", "lm"),
         "nls",
         c("ols", "rms", "lm"),
+        "ordinal_weightit",
         c("orm", "rms"),
         c("oohbchoice", "dbchoice"),
         "phylolm",
         "phyloglm",
         c("plm", "panelmodel"),
         "polr",
+        "stpm2","gsm","pstpm2","aft",
         "Rchoice",
         "rendo.base",
         "rlmerMod",
